@@ -39,7 +39,6 @@ function init() {
 	win = new Window('log', {top:10, left:10, width:400, height:250, zIndex: 100, resizable: true, title: "Log", hideEffect: Effect.SwitchOff})
 	win.getContent().innerHTML= "&nbsp;";
 	timerID  = setTimeout("UpdateTimer()", 1000);
-    tipobj=document.all? document.all["dhtmltooltip"] : document.getElementById? document.getElementById("dhtmltooltip") : ""
 };
 -->
 </script>
@@ -49,7 +48,6 @@ function init() {
   <script type="text/javascript" src="js/effects.js"> </script>
   <script type="text/javascript" src="js/window.js"> </script>
   <script type="text/javascript" src="js/base64.js"> </script>
-  <script type="text/javascript" src="js/dhtmltooltip.js"> </script>
   <script type="text/javascript" src="js/scriptaculous.js"> </script>
   <script type="text/javascript" src="js/operator.js"> </script>
 
@@ -57,18 +55,21 @@ function init() {
 </head>
 
 <body>
+  <script type="text/javascript" src="js/wz_tooltip.js"> </script>
 <a href='javascript: win.showCenter();'><img src='images/bug.png' border=0></a>
 <?
 for($a=1;$a<=$buttoncount;$a++)
 {
 $mouseov=" onmouseover='javascript:$(\"mcount$a\").style.display=\"block\";' onmouseout='javascript:$(\"mcount$a\").style.display=\"none\";' ";
-$mouseov1 = " onMouseover=\"ddrivetip(this,'#f0a020', 180)\"; onMouseout=\"hideddrivetip()\" ";
-$mouseov2 = " onMouseover=\"ddrivetip(this,'#f0a020', 180)\"; onMouseout=\"hideddrivetip()\" ";
+$mouseov1 = " onMouseover=\"TagToTip('mwitip$a')\"; onMouseout=\"UnTip()\" ";
+$mouseov2 = " onMouseover=\"TagToTip('phonetip$a')\"; onMouseout=\"UnTip()\" ";
 echo "<div id=\"boton$a\" class='free' style='display: none;'>\n";
 echo "<span id='label$a'>&nbsp;</span><BR>\n";
 echo "<span id='clid$a' class='clid'>&nbsp;</span><BR>\n";
 echo "<div class='clid' id='tick$a'>&nbsp;</div>";
 echo "<div id='phone$a' class='phone1' $mouseov2>&nbsp;</div>";
+echo "<span id='phonetip$a'></span>";
+echo "<span id='mwitip$a'></span>";
 echo "<div id='mwi$a' class='mwi' $mouseov1>&nbsp;</div>";
 echo "</div>\n";
 } 
@@ -81,14 +82,13 @@ echo "</div>\n";
 </div>
 
 <div align='center'>
-<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,0,0" width="1" height="1" id="operator">
+<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,0,0" width="100" height="100" id="operator">
 <param name="allowScriptAccess" value="sameDomain" />
 <param name="movie" value="comunicator.swf?context=<?=$contexto?>" />
 <param name="quality" value="high" />
 <param name="scale" value="noScale" />
 <param name="bgcolor" value="#ffffff" />
-<embed src="comunicator.swf?context=<?=$contexto?>" scale="noScale" quality="high" bgcolor="#ffffff" width="1" height="1" name="operator" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" swLiveConnect="true"/>
+<embed src="comunicator.swf?context=<?=$contexto?>" scale="noScale" quality="high" bgcolor="#ffffff" width="100" height="100" name="operator" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" swLiveConnect="true"/>
 </div>
-<div id="dhtmltooltip"></div>
 </body>
 </html>
