@@ -1,5 +1,3 @@
-info  = new Object();
-mwiinfo  = new Object();
 Event.observe(window, 'load', init, false);
 
 function operator_DoFSCommand(command, args) {
@@ -146,11 +144,11 @@ function docommand(nro,comando,texto) {
 			}
 		}
 	}
-    	
-	if(comando=="park") {
-        	boton.className="park";
-        	clid.innerHTML=texto;
-    	}
+
+    if(comando=="park") { 
+        boton.className="park"; 
+        clid.innerHTML=texto; 
+    } 
 
 	if(comando ==  "settext") {
 		clid.innerHTML=texto;
@@ -161,7 +159,7 @@ function docommand(nro,comando,texto) {
         var textodecode = decodeBase64(texto);
         var i = textodecode.indexOf("\n");
 		textodecode = replace(textodecode,'\n','<BR>');
-		info["phone"+nro]=textodecode;
+	    $('phonetip'+nro).innerHTML=textodecode;
     }
 
 	if(comando == "settimer") {
@@ -219,7 +217,7 @@ function docommand(nro,comando,texto) {
 		}
 	}
 	if(comando == "voicemailcount") {
-		mwiinfo["mwi"+nro]=texto;
+	    $('mwitip'+nro).innerHTML=texto;
 	}
 
 }
