@@ -7,8 +7,8 @@
 # source function library
 . /etc/rc.d/init.d/functions
 
-DAEMON=/usr/local/operator/op_server.pl
-OPTIONS=-d
+DAEMON=/usr/local/fop/op_server.pl
+OPTIONS="-d -c /etc/asterisk/fop"
 RETVAL=0
 
 case "$1" in
