@@ -139,9 +139,6 @@ function handleXML(doc){
 			if (comando == "restrict") {
 				_global.restrict = numeroboton;
                 _global.mybutton = numeroboton;
-				var myresa = eval('_root.resaltado'+_global.restrict);
-				myresa._visible = true;
-				return;
 			}
 
 			if (comando == "version") {
@@ -154,7 +151,13 @@ function handleXML(doc){
 			}
 
 			if (_root.context == boton_contexto) {
-				colaEvento(boton_numero,comando,textofinal);
+				if(_global.restrict != undefined) {
+					if(_global.restrict == boton_numero) {
+						colaEvento(boton_numero,comando,textofinal);
+					}
+				} else {
+					colaEvento(boton_numero,comando,textofinal);
+				}
 			}
 			// endif root.context
 		}
